from distutils.core import setup

setup(
    name         = 'distribution_py_710',
    version      = '1.0.0',
    py_modules   = ['distribution_py_710'],
    author       = 'py710839160',
    author_email = '710839160@qq.com',
    url          = 'http://www.python.org',
    description  = 'A start',
    )
